==> zio-aws-athena_3-5.17.123.1-sources.jar: zio/aws/athena/model/AthenaError.scala <==
package zio.aws.athena.model
import java.lang.Integer
import zio.aws.athena.model.primitives.ErrorCategory
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AthenaError(errorCategory: Option[ErrorCategory] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.AthenaError = {
    import AthenaError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.AthenaError
      .builder()
      .optionallyWith(
        errorCategory.map(value => ErrorCategory.unwrap(value): Integer)
      )(_.errorCategory)
      .build()
  }
  def asReadOnly: zio.aws.athena.model.AthenaError.ReadOnly =
    zio.aws.athena.model.AthenaError.wrap(buildAwsValue())
}
object AthenaError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.AthenaError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.AthenaError =
      zio.aws.athena.model.AthenaError(errorCategory.map(value => value))
    def errorCategory: Option[ErrorCategory]
    def getErrorCategory: ZIO[Any, AwsError, ErrorCategory] =
      AwsError.unwrapOptionField("errorCategory", errorCategory)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.AthenaError
  ) extends zio.aws.athena.model.AthenaError.ReadOnly {
    override val errorCategory: Option[ErrorCategory] = scala
      .Option(impl.errorCategory())
      .map(value => zio.aws.athena.model.primitives.ErrorCategory(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.AthenaError
  ): zio.aws.athena.model.AthenaError.ReadOnly = new Wrapper(impl)
}

==> zio-aws-athena_3-5.17.155.2-sources.jar: zio/aws/athena/model/AthenaError.scala <==
package zio.aws.athena.model
import java.lang.Integer
import zio.aws.athena.model.primitives.{ErrorType, ErrorCategory}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AthenaError(
    errorCategory: Option[ErrorCategory] = None,
    errorType: Option[ErrorType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.AthenaError = {
    import AthenaError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.AthenaError
      .builder()
      .optionallyWith(
        errorCategory.map(value => ErrorCategory.unwrap(value): Integer)
      )(_.errorCategory)
      .optionallyWith(errorType.map(value => ErrorType.unwrap(value): Integer))(
        _.errorType
      )
      .build()
  }
  def asReadOnly: zio.aws.athena.model.AthenaError.ReadOnly =
    zio.aws.athena.model.AthenaError.wrap(buildAwsValue())
}
object AthenaError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.AthenaError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.AthenaError =
      zio.aws.athena.model.AthenaError(
        errorCategory.map(value => value),
        errorType.map(value => value)
      )
    def errorCategory: Option[ErrorCategory]
    def errorType: Option[ErrorType]
    def getErrorCategory: ZIO[Any, AwsError, ErrorCategory] =
      AwsError.unwrapOptionField("errorCategory", errorCategory)
    def getErrorType: ZIO[Any, AwsError, ErrorType] =
      AwsError.unwrapOptionField("errorType", errorType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.AthenaError
  ) extends zio.aws.athena.model.AthenaError.ReadOnly {
    override val errorCategory: Option[ErrorCategory] = scala
      .Option(impl.errorCategory())
      .map(value => zio.aws.athena.model.primitives.ErrorCategory(value))
    override val errorType: Option[ErrorType] = scala
      .Option(impl.errorType())
      .map(value => zio.aws.athena.model.primitives.ErrorType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.AthenaError
  ): zio.aws.athena.model.AthenaError.ReadOnly = new Wrapper(impl)
}
